# AlterationDurationChallengeSummaryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**work_reference_number** | **str** |  | 
**permit_reference_number** | **str** |  | 
**alteration_reference_number** | **str** |  | 
**location_description** | **str** |  | 
**street** | **str** |  | 
**town** | **str** |  | 
**area** | **str** |  | 
**usrn** | **float** |  | 
**promoter_swa_code** | **str** |  | 
**promoter_organisation** | **str** |  | 
**highway_authority** | **str** |  | 
**proposed_start_date** | **datetime** |  | 
**proposed_end_date** | **datetime** |  | 
**proposed_start_time** | **datetime** |  | [optional] 
**proposed_end_time** | **datetime** |  | [optional] 
**actual_start_date** | **datetime** |  | [optional] 
**actual_end_date** | **datetime** |  | [optional] 
**reasonable_period_end_date** | **datetime** |  | 
**status_changed_date** | **datetime** |  | 
**duration_challenge_review_status** | **AllOfAlterationDurationChallengeSummaryResponseDurationChallengeReviewStatus** |  | [optional] 
**duration_challenge_review_status_string** | **str** |  | [optional] 
**duration_challenge_review_update_date** | **datetime** |  | [optional] 
**duration_challenge_non_acceptance_response_status** | **AllOfAlterationDurationChallengeSummaryResponseDurationChallengeNonAcceptanceResponseStatus** |  | [optional] 
**duration_challenge_non_acceptance_response_status_string** | **str** |  | [optional] 
**duration_challenge_non_acceptance_response_update_date** | **datetime** |  | [optional] 
**duration_challenge_follow_up_review_complete** | **bool** |  | [optional] 
**work_status** | [**WorkStatusResponse**](WorkStatusResponse.md) |  | 
**work_status_string** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

